pub struct ManifoldLaneSet<M: RawMutex + 'static, const LANE_COUNT: usize, const NOTIFY: usize> { /* private fields */ }Implementations
Sourceimpl<M: RawMutex + Sync + 'static, const LANE_COUNT: usize, const NOTIFY: usize> ManifoldLaneSet<M, LANE_COUNT, NOTIFY>
impl<M: RawMutex + Sync + 'static, const LANE_COUNT: usize, const NOTIFY: usize> ManifoldLaneSet<M, LANE_COUNT, NOTIFY>
pub fn new() -> Self
pub fn claim_interface<const FRAME: usize, const INBOUND_DEPTH: usize, const OUTBOUND_DEPTH: usize>( &mut self, storage: &'static StaticManifoldLane<M, FRAME, INBOUND_DEPTH, OUTBOUND_DEPTH>, descriptor: InterfaceDescriptor, ) -> Result<InterfaceLane<M, FRAME>, LaneClaimError>
Sourcepub fn claim_interface_with_outbound_buffer<const FRAME: usize, const INBOUND_DEPTH: usize, const OUTBOUND_DEPTH: usize>(
&mut self,
storage: &'static StaticManifoldLane<M, FRAME, INBOUND_DEPTH, OUTBOUND_DEPTH>,
descriptor: InterfaceDescriptor,
outbound_buffer: &'static mut [FrameSlot<FRAME>],
) -> Result<InterfaceLane<M, FRAME>, LaneClaimError>
pub fn claim_interface_with_outbound_buffer<const FRAME: usize, const INBOUND_DEPTH: usize, const OUTBOUND_DEPTH: usize>( &mut self, storage: &'static StaticManifoldLane<M, FRAME, INBOUND_DEPTH, OUTBOUND_DEPTH>, descriptor: InterfaceDescriptor, outbound_buffer: &'static mut [FrameSlot<FRAME>], ) -> Result<InterfaceLane<M, FRAME>, LaneClaimError>
Claims an interface whose outbound frame ring lives in caller-owned static storage.
pub fn claim_interface_with_ifac<const FRAME: usize, const INBOUND_DEPTH: usize, const OUTBOUND_DEPTH: usize>( &mut self, storage: &'static StaticManifoldLane<M, FRAME, INBOUND_DEPTH, OUTBOUND_DEPTH>, descriptor: InterfaceDescriptor, context: IfacContext, ) -> Result<InterfaceLane<M, FRAME>, LaneClaimError>
pub fn claim_supervisor<const FRAME: usize, const INBOUND_DEPTH: usize, const OUTBOUND_DEPTH: usize>( &mut self, storage: &'static StaticManifoldLane<M, FRAME, INBOUND_DEPTH, OUTBOUND_DEPTH>, supervisor: InterfaceId, outbound_wake: &'static Signal<M, ()>, ) -> Result<SupervisorLane<M, FRAME>, LaneClaimError>
Sourcepub fn claim_supervisor_with_outbound_buffer<const FRAME: usize, const INBOUND_DEPTH: usize, const OUTBOUND_DEPTH: usize>(
&mut self,
storage: &'static StaticManifoldLane<M, FRAME, INBOUND_DEPTH, OUTBOUND_DEPTH>,
supervisor: InterfaceId,
outbound_wake: &'static Signal<M, ()>,
outbound_buffer: &'static mut [FrameSlot<FRAME>],
) -> Result<SupervisorLane<M, FRAME>, LaneClaimError>
pub fn claim_supervisor_with_outbound_buffer<const FRAME: usize, const INBOUND_DEPTH: usize, const OUTBOUND_DEPTH: usize>( &mut self, storage: &'static StaticManifoldLane<M, FRAME, INBOUND_DEPTH, OUTBOUND_DEPTH>, supervisor: InterfaceId, outbound_wake: &'static Signal<M, ()>, outbound_buffer: &'static mut [FrameSlot<FRAME>], ) -> Result<SupervisorLane<M, FRAME>, LaneClaimError>
Claims a supervisor whose outbound frame ring lives in caller-owned static storage.
This keeps a large burst queue out of scarce internal RAM on targets with a separately
initialized external-memory allocator. Inbound storage and notification accounting remain
those declared by INBOUND_DEPTH.
pub fn claim_supervisor_with_ifac<const FRAME: usize, const INBOUND_DEPTH: usize, const OUTBOUND_DEPTH: usize>( &mut self, storage: &'static StaticManifoldLane<M, FRAME, INBOUND_DEPTH, OUTBOUND_DEPTH>, supervisor: InterfaceId, context: IfacContext, outbound_wake: &'static Signal<M, ()>, ) -> Result<SupervisorLane<M, FRAME>, LaneClaimError>
pub fn into_manifold_wiring<const COMMANDS: usize, const LIFECYCLE: usize, const COMPLETIONS: usize>( self, notify: Receiver<'static, M, InterfaceId, NOTIFY>, commands: Receiver<'static, M, IssuedCommand, COMMANDS>, lifecycle: Receiver<'static, M, InterfaceLifecycle, LIFECYCLE>, handle: PrnsNodeHandle<'static, M, COMMANDS, COMPLETIONS>, ) -> ManifoldWiring<M, LANE_COUNT, NOTIFY, COMMANDS, LIFECYCLE, COMPLETIONS>